@@ -24,6 +24,7 @@ pub struct KeyConfig {
   pub select_all: KeyCode,
   pub undo: KeyCode,
   pub edit: KeyCode,
+  pub duplicate: KeyCode,
   pub modify: KeyCode,
   pub shell: KeyCode,
   pub log: KeyCode,
@@ -35,6 +36,10 @@ pub struct KeyConfig {
   pub context_menu: KeyCode,
   pub next_tab: KeyCode,
   pub previous_tab: KeyCode,
+  pub priority_h: KeyCode,
+  pub priority_m: KeyCode,
+  pub priority_l: KeyCode,
+  pub priority_n: KeyCode,
   pub shortcut0: KeyCode,
   pub shortcut1: KeyCode,
   pub shortcut2: KeyCode,
@@ -66,6 +71,7 @@ impl Default for KeyConfig {
       select_all: KeyCode::Char('V'),
       undo: KeyCode::Char('u'),
       edit: KeyCode::Char('e'),
+      duplicate: KeyCode::Char('y'),
       modify: KeyCode::Char('m'),
       shell: KeyCode::Char('!'),
       log: KeyCode::Char('l'),
@@ -77,6 +83,10 @@ impl Default for KeyConfig {
       context_menu: KeyCode::Char('c'),
       next_tab: KeyCode::Char(']'),
       previous_tab: KeyCode::Char('['),
+      priority_h: KeyCode::Char('H'),
+      priority_m: KeyCode::Char('M'),
+      priority_l: KeyCode::Char('L'),
+      priority_n: KeyCode::Char('N'),
       shortcut0: KeyCode::Char('0'),
       shortcut1: KeyCode::Char('1'),
       shortcut2: KeyCode::Char('2'),
@@ -115,6 +125,7 @@ impl KeyConfig {
     let select_all = Self::get_config("uda.taskwarrior-tui.keyconfig.select-all", data);
     let undo = Self::get_config("uda.taskwarrior-tui.keyconfig.undo", data);
     let edit = Self::get_config("uda.taskwarrior-tui.keyconfig.edit", data);
+    let duplicate = Self::get_config("uda.taskwarrior-tui.keyconfig.duplicate", data);
     let modify = Self::get_config("uda.taskwarrior-tui.keyconfig.modify", data);
     let shell = Self::get_config("uda.taskwarrior-tui.keyconfig.shell", data);
     let log = Self::get_config("uda.taskwarrior-tui.keyconfig.log", data);
@@ -125,6 +136,16 @@ impl KeyConfig {
     let context_menu = Self::get_config("uda.taskwarrior-tui.keyconfig.context-menu", data);
     let next_tab = Self::get_config("uda.taskwarrior-tui.keyconfig.next-tab", data);
     let previous_tab = Self::get_config("uda.taskwarrior-tui.keyconfig.previous-tab", data);
+    let shortcut0 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut0", data);
+    let shortcut1 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut1", data);
+    let shortcut2 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut2", data);
+    let shortcut3 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut3", data);
+    let shortcut4 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut4", data);
+    let shortcut5 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut5", data);
+    let shortcut6 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut6", data);
+    let shortcut7 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut7", data);
+    let shortcut8 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut8", data);
+    let shortcut9 = Self::get_config("uda.taskwarrior-tui.keyconfig.shortcut9", data);
 
     self.quit = quit.unwrap_or(self.quit);
     self.refresh = refresh.unwrap_or(self.refresh);
@@ -142,6 +163,7 @@ impl KeyConfig {
     self.select_all = select_all.unwrap_or(self.select_all);
     self.undo = undo.unwrap_or(self.undo);
     self.edit = edit.unwrap_or(self.edit);
+    self.duplicate = edit.unwrap_or(self.duplicate);
     self.modify = modify.unwrap_or(self.modify);
     self.shell = shell.unwrap_or(self.shell);
     self.log = log.unwrap_or(self.log);
@@ -152,6 +174,16 @@ impl KeyConfig {
     self.context_menu = context_menu.unwrap_or(self.context_menu);
     self.next_tab = next_tab.unwrap_or(self.next_tab);
     self.previous_tab = previous_tab.unwrap_or(self.previous_tab);
+    self.shortcut0 = shortcut0.unwrap_or(self.shortcut0);
+    self.shortcut1 = shortcut1.unwrap_or(self.shortcut1);
+    self.shortcut2 = shortcut2.unwrap_or(self.shortcut2);
+    self.shortcut3 = shortcut3.unwrap_or(self.shortcut3);
+    self.shortcut4 = shortcut4.unwrap_or(self.shortcut4);
+    self.shortcut5 = shortcut5.unwrap_or(self.shortcut5);
+    self.shortcut6 = shortcut6.unwrap_or(self.shortcut6);
+    self.shortcut7 = shortcut7.unwrap_or(self.shortcut7);
+    self.shortcut8 = shortcut8.unwrap_or(self.shortcut8);
+    self.shortcut9 = shortcut9.unwrap_or(self.shortcut9);
 
     self.check()
   }
@@ -174,6 +206,7 @@ impl KeyConfig {
       &self.quick_tag,
       &self.undo,
       &self.edit,
+      &self.duplicate,
       &self.modify,
       &self.shell,
       &self.log,
